@@ -22,9 +22,14 @@
 //! ```
 
 mod lex;
+mod lossless;
 mod parse;
 
-pub use parse::{Error, Identifier, Include, Makefile, ParseError, Rule, VariableDefinition};
+pub use lossless::{
+    ArchiveMember, ArchiveMembers, Error, Identifier, Include, Lang, Makefile, ParseError, Rule,
+    VariableDefinition,
+};
+pub use parse::Parse;
 
 #[derive(Debug, Clone, Copy, PartialEq, Eq, PartialOrd, Ord, Hash)]
 #[allow(non_camel_case_types)]
@@ -57,6 +62,10 @@ pub enum SyntaxKind {
     // Directives
     CONDITIONAL,
     INCLUDE,
+
+    // Archive members
+    ARCHIVE_MEMBERS, // Container for just the members inside parentheses
+    ARCHIVE_MEMBER,  // Individual member like "bar.o" or "baz.o"
 }
 
 /// Convert our `SyntaxKind` into the rowan `SyntaxKind`.
